Changelog
=========

1.1.0
-----

* Support for additional encodings, selectable at runtime:
  * `SIMPLE_QUOTING`
  * `QUERY_QUOTING`
  * `PATH_SEGMENT_QUOTING`
  * `USERINFO_QUOTING`

1.0.0
-----

* Initial Release. Provides two functions:
  * `quote`
  * `unquote`
